import 'package:protonimage/src/core/dependencies.dart';

// Accessing the configurations from BaseShimmerConfig
Color baseColor = BaseShimmerConfig.baseColor;
Color highlightColor = BaseShimmerConfig.highlightColor;
Color blackColor = BaseShimmerConfig.blackColor;
Color whiteColor = BaseShimmerConfig.whiteColor;

// Accessing the configurations from BaseComponentConfig
double aspectRatio = BaseComponentConfig.aspectRatio;
BoxFit boxFit = BaseComponentConfig.boxFit;

/// A widget for displaying images with customizable shimmer effects and overlay gradients.
class ProtonImage extends StatelessWidget {
  /// The URL path of the image.
  final String path;

  /// The height of the container.
  final double height;

  /// The radius of the container.
  final double radius;

  /// The BoxFit for the image.
  final BoxFit imgBoxfit;

  /// The aspect ratio of the image.
  final double aspectRatio;

  /// The base color of the shimmer effect.
  final Color baseColor;

  /// The highlight color of the shimmer effect.
  final Color highlightColor;

  /// The background color of the container.
  final Color backgroundColor;

  /// The gradient overlay for the image.
  final Gradient? overlayGradient;

  /// Creates a ProtonImage widget.
  const ProtonImage({
    super.key,
    required this.path,
    required this.height,
    required this.radius,
    this.imgBoxfit = BoxFit.cover,
    this.aspectRatio = BaseComponentConfig.aspectRatio,
    this.backgroundColor = BaseShimmerConfig.whiteColor,
    this.baseColor = BaseShimmerConfig.baseColor,
    this.highlightColor = BaseShimmerConfig.highlightColor,
    this.overlayGradient,
  });

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: height,
      child: AspectRatio(
        aspectRatio: aspectRatio,
        child: Stack(
          children: [
            Transform.scale(
              scale: BaseComponentConfig.transferScale,
              child: Shimmer.fromColors(
                baseColor: baseColor,
                highlightColor: highlightColor,
                child: Container(
                  decoration: BoxDecoration(
                    borderRadius: BorderRadius.circular(radius),
                    color: backgroundColor,
                  ),
                ),
              ),
            ),
            Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(radius),
                image: DecorationImage(
                  fit: imgBoxfit,
                  image: NetworkImage(path),
                ),
                gradient: overlayGradient,
              ),
            ),
          ],
        ),
      ),
    );
  }
}
